pub struct Barcode {
pub alt_text: Option<String>,
pub format: BarcodeFormat,
pub message: String,
pub message_encoding: String,
}Expand description
Information specific to the pass’s barcode. Deprecated in iOS 9.0 and later; use barcodes instead.
Information about a pass’s barcode.
Fields
alt_text: Option<String>Text displayed near the barcode. For example, a human-readable version of the barcode data in case the barcode doesn’t scan.
format: BarcodeFormatBarcode format. PKBarcodeFormatCode128 may only be used for dictionaries in the barcodes array.
message: StringMessage or payload to be displayed as a barcode.
message_encoding: StringText encoding that is used to convert the message from the string representation to a data representation to render the barcode. The value is typically iso-8859-1, but you may use another encoding that is supported by your barcode scanning infrastructure.
Implementations