BoardingPass

Struct BoardingPass 

pub struct BoardingPass {
    pub transit_type: TransitType,
    pub auxiliary_fields: Option<Vec<Field>>,
    pub back_fields: Option<Vec<Field>>,
    pub header_fields: Option<Vec<Field>>,
    pub primary_fields: Option<Vec<Field>>,
    pub secondary_fields: Option<Vec<Field>>,
}
Information specific to a boarding pass.

Keys that define the structure of the pass. These keys are used for all pass styles and partition the fields into the various parts of the pass.

Fields

transit_type: TransitType

Type of transit.

auxiliary_fields: Option<Vec<Field>>

Additional fields to be displayed on the front of the pass.

back_fields: Option<Vec<Field>>

Fields to be on the back of the pass.

header_fields: Option<Vec<Field>>

Fields to be displayed in the header on the front of the pass.Use header fields sparingly; unlike all other fields, they remain visible when a stack of passes are displayed.

primary_fields: Option<Vec<Field>>

Fields to be displayed prominently on the front of the pass.

secondary_fields: Option<Vec<Field>>

Fields to be displayed on the front of the pass.

Implementations

Source

impl BoardingPass

pub fn new(transit_type: TransitType) -> Self

Create a new Instance