Nfc

Struct Nfc 

pub struct Nfc {
    pub encryption_public_key: Option<String>,
    pub message: String,
}
Information used for Value Added Service Protocol transactions. Available in iOS 9.0.

Information about the NFC payload passed to an Apple Pay terminal.

Fields

encryption_public_key: Option<String>

The public encryption key used by the Value Added Services protocol. Use a Base64 encoded X.509 SubjectPublicKeyInfo structure containing a ECDH public key for group P256.

message: String

The payload to be transmitted to the Apple Pay terminal. Must be 64 bytes or less. Messages longer than 64 bytes are truncated by the system.

Implementations

Source

impl Nfc

pub fn new(message: &str) -> Self

Create a new Instance