pub struct PersonNameComponents {
pub family_name: Option<String>,
pub given_name: Option<String>,
pub middle_name: Option<String>,
pub name_prefix: Option<String>,
pub name_suffix: Option<String>,
pub nickname: Option<String>,
pub phonetic_representation: Box<Option<PhoneticRepresentation>>,
}Expand description
The passenger’s name.
An object that manages the separate parts of a person’s name
Fields
family_name: Option<String>Name bestowed upon an individual to denote membership in a group or family.
given_name: Option<String>Name bestowed upon an individual to differentiate them from other members of a group that share a family name.
middle_name: Option<String>Secondary name bestowed upon an individual to differentiate them from others that have the same given name.
name_prefix: Option<String>The portion of a name’s full form of address that precedes the name itself.
name_suffix: Option<String>The portion of a name’s full form of address that follows the name itself.
nickname: Option<String>Name substituted for the purposes of familiarity.
phonetic_representation: Box<Option<PhoneticRepresentation>>The phonetic representation name components of the receiver.
Implementations