pub struct Semantics {Show 66 fields
pub airline_code: Option<String>,
pub artist_i_ds: Option<Vec<String>>,
pub away_team_abbreviation: Option<String>,
pub away_team_location: Option<String>,
pub away_team_name: Option<String>,
pub balance: Option<CurrencyAmount>,
pub boarding_group: Option<String>,
pub boarding_sequence_number: Option<String>,
pub car_number: Option<String>,
pub confirmation_number: Option<String>,
pub current_arrival_date: Option<String>,
pub current_boarding_date: Option<String>,
pub current_departure_date: Option<String>,
pub departure_airport_code: Option<String>,
pub departure_airport_name: Option<String>,
pub departure_gate: Option<String>,
pub departure_location: Option<Location>,
pub departure_location_description: Option<String>,
pub departure_platform: Option<String>,
pub departure_station_name: Option<String>,
pub departure_terminal: Option<String>,
pub destination_airport_code: Option<String>,
pub destination_airport_name: Option<String>,
pub destination_gate: Option<String>,
pub destination_location: Option<Location>,
pub destination_location_description: Option<Location>,
pub destination_platform: Option<String>,
pub destination_station_name: Option<String>,
pub destination_terminal: Option<String>,
pub duration: Option<f64>,
pub event_end_date: Option<String>,
pub event_name: Option<String>,
pub event_start_date: Option<String>,
pub event_type: Option<EventType>,
pub flight_code: Option<String>,
pub flight_number: Option<f64>,
pub genre: Option<String>,
pub home_team_abbreviation: Option<String>,
pub home_team_location: Option<String>,
pub home_team_name: Option<String>,
pub league_abbreviation: Option<String>,
pub league_name: Option<String>,
pub membership_program_name: Option<String>,
pub membership_program_number: Option<String>,
pub original_arrival_date: Option<String>,
pub original_boarding_date: Option<String>,
pub original_departure_date: Option<String>,
pub passenger_name: Option<PersonNameComponents>,
pub performer_names: Option<Vec<String>>,
pub priority_status: Option<String>,
pub seats: Option<Vec<Seat>>,
pub security_screening: Option<String>,
pub silence_requested: Option<bool>,
pub sport_name: Option<String>,
pub total_price: Option<CurrencyAmount>,
pub transit_provider: Option<String>,
pub transit_status: Option<String>,
pub transit_status_reason: Option<String>,
pub vehicle_name: Option<String>,
pub vehicle_number: Option<String>,
pub vehicle_type: Option<String>,
pub venue_entrance: Option<String>,
pub venue_location: Option<Location>,
pub venue_name: Option<String>,
pub venue_phone_number: Option<String>,
pub venue_room: Option<String>,
}Expand description
Machine-readable metadata to allow the system to offer Wallet passes to users intelligently.
Fields
airline_code: Option<String>The IATA airline code, such as ‘EX’ for flightCode ‘EX123’.
artist_i_ds: Option<Vec<String>>The Adam IDs for the artists performing, in decreasing order of significance.
away_team_abbreviation: Option<String>The unique abbreviation of the away team’s name.
away_team_location: Option<String>The home location of the away team.
away_team_name: Option<String>The name of the away team.
balance: Option<CurrencyAmount>The balance redeemable with the pass.
boarding_group: Option<String>A group number for boarding.
boarding_sequence_number: Option<String>A sequence number for boarding.
car_number: Option<String>The car number.
confirmation_number: Option<String>A booking or reservation confirmation number.
current_arrival_date: Option<String>The updated date and time of arrival, if different than the original scheduled date.
current_boarding_date: Option<String>The updated date and time of boarding, if different than the original scheduled date.
current_departure_date: Option<String>The updated date and time of departure, if different than the original scheduled date.
departure_airport_code: Option<String>The IATA airport code for the departure airport.
departure_airport_name: Option<String>The full name of the departure airport
departure_gate: Option<String>The gate number or letters of the departure gate, such as ‘1A’. Do not include the word ‘Gate’.
departure_location: Option<Location>The geographic coordinates of the transit departure, suitable to be shown on a map. If possible, precise locations are more useful to travelers, such as the specific location of the gate at an airport.
departure_location_description: Option<String>A brief description of the departure location.
departure_platform: Option<String>The name of the departure platform, such as ‘A’. Do not include the word ‘Platform’.
departure_station_name: Option<String>The name of the departure station.
departure_terminal: Option<String>The terminal name or letter of the departure terminal, such as ‘A’. Do not include the word ‘Terminal’
destination_airport_code: Option<String>The IATA airport code for the destination airport.
destination_airport_name: Option<String>The full name of the destination airport
destination_gate: Option<String>The gate number or letters of the destination gate, such as ‘1A’. Do not include the word ‘Gate’.
destination_location: Option<Location>The geographic coordinates of the transit destination, suitable to be shown on a map.
destination_location_description: Option<Location>A brief description of the destination location.
destination_platform: Option<String>The name of the destination platform, such as ‘A’. Do not include the word ‘Platform’.
destination_station_name: Option<String>The name of the destination station.
destination_terminal: Option<String>The terminal name or letter of the destination terminal, such as ‘A’. Do not include the word ‘Terminal’
duration: Option<f64>The duration of the event or transit journey, in seconds.
event_end_date: Option<String>The date and time the event ends.
event_name: Option<String>The full name for the event, such as the title of a movie.
event_start_date: Option<String>The date and time the event starts.
event_type: Option<EventType>The event type.
flight_code: Option<String>The IATA flight code
flight_number: Option<f64>The numeric portion of the IATA flightCode, such as 123 for flightCode ‘EX123’
genre: Option<String>The genre of the performance.
home_team_abbreviation: Option<String>The unique abbreviation of the home team’s name.
home_team_location: Option<String>The home location of the home team.
home_team_name: Option<String>The name of the home team.
league_abbreviation: Option<String>The abbreviated league name for a sporting event.
league_name: Option<String>he unabbreviated league name for a sporting event.
membership_program_name: Option<String>The name of a frequent flyer or loyalty program.
membership_program_number: Option<String>The ticketed passenger’s frequent flyer or loyalty number.
original_arrival_date: Option<String>The original scheduled date and time of arrival.
original_boarding_date: Option<String>The original scheduled date and time of boarding.
original_departure_date: Option<String>The original scheduled date and time of departure.
passenger_name: Option<PersonNameComponents>The passenger’s name.
performer_names: Option<Vec<String>>The full names of the performers and opening acts, in decreasing order of significance.
priority_status: Option<String>he priority status held by the ticketed passenger
seats: Option<Vec<Seat>>Seating details for all seats at the event or transit journey.
security_screening: Option<String>The type of security screening that the ticketed passenger will be subject to, such as ‘Priority’.
silence_requested: Option<bool>Request the user’s device to remain silent during a the event or transit journey. This key may not be honored and the system will determine the length of the silence period.
sport_name: Option<String>The commonly used local name of the sport.
total_price: Option<CurrencyAmount>The total price for the pass.
transit_provider: Option<String>The name of the transit company.
transit_status: Option<String>A brief description of the current status of the vessel being boarded. For delayed statuses, provide currentBoardingDate, currentDepartureDate, and currentArrivalDate where available.
transit_status_reason: Option<String>A brief description explaining the reason for the current transitStatus
vehicle_name: Option<String>The name of the vehicle being boarded, such as the name of a boat.
vehicle_number: Option<String>The identifier of the vehicle being boarded, such as the aircraft registration number or train number.
vehicle_type: Option<String>A brief description of the type of vehicle being boarded, such as the model and manufacturer of a plane or the class of a boat.
venue_entrance: Option<String>The full name of the entrance to use to gain access to the ticketed event.
venue_location: Option<Location>The geographic coordinates of the venue.
venue_name: Option<String>The full name of the venue.
venue_phone_number: Option<String>The phone number for enquiries about the venue’s ticketed event.
venue_room: Option<String>The full name of the room where the ticketed event is taking place.