Struct wallet_pass::template::Beacon [−][src]
pub struct Beacon {
pub major: Option<i64>,
pub minor: Option<i64>,
pub proximity_uuid: String,
pub relevant_text: Option<String>,
}Expand description
Information about a location beacon.
Fields
major: Option<i64>Major identifier of a Bluetooth Low Energy location beacon.
minor: Option<i64>Minor identifier of a Bluetooth Low Energy location beacon.
proximity_uuid: StringUnique identifier of a Bluetooth Low Energy location beacon.
relevant_text: Option<String>Text displayed on the lock screen when the pass is currently relevant.
Implementations