pub struct Details {
pub auxiliary_fields: Option<Vec<Field>>,
pub back_fields: Option<Vec<Field>>,
pub header_fields: Option<Vec<Field>>,
pub primary_fields: Option<Vec<Field>>,
pub secondary_fields: Option<Vec<Field>>,
pub transit_type: Option<TransitType>,
}Expand description
Information specific to a coupon.
Information specific to an event ticket.
Information specific to a generic pass.
Information specific to a store card.
Information specific to a boarding pass.
Keys that define the structure of the pass. These keys are used for all pass styles and partition the fields into the various parts of the pass.
Fields
auxiliary_fields: Option<Vec<Field>>Additional fields to be displayed on the front of the pass.
back_fields: Option<Vec<Field>>Fields to be on the back of the pass.
header_fields: Option<Vec<Field>>Fields to be displayed in the header on the front of the pass. Use header fields sparingly; unlike all other fields, they remain visible when a stack of passes are displayed.
primary_fields: Option<Vec<Field>>Fields to be displayed prominently on the front of the pass.
secondary_fields: Option<Vec<Field>>Fields to be displayed on the front of the pass.
transit_type: Option<TransitType>Type of transit.
Implementations
Sourceimpl Details
impl Details
Sourcepub fn transit_type(&mut self, transit_type: TransitType)
pub fn transit_type(&mut self, transit_type: TransitType)
Type of transit.
Sourcepub fn add_auxiliary_field(&mut self, field: Field)
pub fn add_auxiliary_field(&mut self, field: Field)
Add additional field to be displayed on the front of the pass.
Sourcepub fn clear_auxiliary_fields(&mut self)
pub fn clear_auxiliary_fields(&mut self)
Remove additional fields to be displayed on the front of the pass.
Sourcepub fn add_back_field(&mut self, field: Field)
pub fn add_back_field(&mut self, field: Field)
Add field to be on the back of the pass.
Sourcepub fn clear_back_fields(&mut self)
pub fn clear_back_fields(&mut self)
Remove fields to be on the back of the pass.
Sourcepub fn add_header_field(&mut self, field: Field)
pub fn add_header_field(&mut self, field: Field)
Add field to be displayed in the header on the front of the pass. Use header fields sparingly; unlike all other fields, they remain visible when a stack of passes are displayed.
Sourcepub fn clear_header_fields(&mut self)
pub fn clear_header_fields(&mut self)
Remove fields to be displayed in the header on the front of the pass. Use header fields sparingly; unlike all other fields, they remain visible when a stack of passes are displayed.
Sourcepub fn add_primary_field(&mut self, field: Field)
pub fn add_primary_field(&mut self, field: Field)
Add field to be displayed prominently on the front of the pass.
Sourcepub fn clear_primary_fields(&mut self)
pub fn clear_primary_fields(&mut self)
Remove fields to be displayed prominently on the front of the pass.
Sourcepub fn add_secondary_field(&mut self, field: Field)
pub fn add_secondary_field(&mut self, field: Field)
Add field to be displayed on the front of the pass.
Sourcepub fn clear_secondary_fields(&mut self)
pub fn clear_secondary_fields(&mut self)
Remove fields to be displayed on the front of the pass.