pub struct Location {
    pub altitude: Option<f64>,
    pub latitude: f64,
    pub longitude: f64,
    pub relevant_text: Option<String>,
}
The geographic coordinates of the transit departure, suitable to be shown on a map. If possible, precise locations are more useful to travelers, such as the specific location of the gate at an airport.

Information about a location.

The geographic coordinates of the transit destination, suitable to be shown on a map.

A brief description of the destination location.

The geographic coordinates of the venue.

Fields

altitude: Option<f64>

Altitude, in meters, of the location.

latitude: f64

Latitude, in degrees, of the location.

longitude: f64

Longitude, in degrees, of the location.

relevant_text: Option<String>

Text displayed on the lock screen when the pass is currently relevant.

Implementations

Create a new Instance